#!/bin/sh
echo 'name: statistics
version: 0.10.3.1
id: statistics-0.10.3.1-3c8c68df3d16684f829d993d02485f05

license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage: https://github.com/bos/statistics
package-url:
synopsis: A library of statistical types, data, and functions
description: This library provides a number of common functions and types useful
             in statistics.  We focus on high performance, numerical robustness,
             and use of good algorithms.  Where possible, we provide
             references to the statistical literature.
             .
             The library'\''s facilities can be divided into four broad categories:
             .
             * Working with widely used discrete and continuous probability
             distributions.  (There are dozens of exotic distributions in use;
             we focus on the most common.)
             .
             * Computing with sample data: quantile estimation, kernel density
             estimation, histograms, bootstrap methods, significance testing,
             and autocorrelation analysis.
             .
             * Random variate generation under several different distributions.
             .
             * Common statistical tests for significant differences between
             samples.
             .
             Changes in 0.10.3.0
             .
             * Bug fixes
             .
             Changes in 0.10.2.0
             .
             * Bugs in DCT and IDCT are fixed.
             .
             * Accesors for uniform distribution are added.
             .
             * '\''ContGen'\'' instances for all continous distribtuions are added.
             .
             * Beta distribution is added.
             .
             * Constructor for improper gamma distribtuion is added.
             .
             * Binomial distribution allows zero trials.
             .
             * Poisson distribution now accept zero parameter.
             .
             * Integer overflow in caculation of Wilcoxon-T test is fixed.
             .
             * Bug in '\''ContGen'\'' instance for normal distribution is fixed.
             .
             Changes in 0.10.1.0
             .
             * Kolmogorov-Smirnov nonparametric test added.
             .
             * Pearson'\''s chi squared test added.
             .
             * Type class for generating random variates for given distribution
             is added.
             .
             * Modules '\''Statistics.Math'\'' and '\''Statistics.Constants'\'' are moved to
             the @math-functions@ package. They are still available but marked
             as deprecated.
             .
             Changed in 0.10.0.1
             .
             * @dct@ and @idct@ now have type @Vector Double -> Vector Double@
             .
             Changes in 0.10.0.0:
             .
             * The type classes @Mean@ and @Variance@ are split in two. This is
             required for distributions which do not have finite variance or
             mean.
             .
             * The @S.Sample.KernelDensity@ module has been renamed, and
             completely rewritten to be much more robust.  The older module
             oversmoothed multi-modal data.  (The older module is still
             available under the name @S.Sample.KernelDensity.Simple@).
             .
             * Histogram computation is added, in @S.Sample.Histogram@.
             .
             * Forward and inverse discrete Fourier and cosine transforms are
             added, in @S.Transform@.
             .
             * Root finding is added, in @S.Math.RootFinding@.
             .
             * The @complCumulative@ function is added to the @Distribution@
             class in order to accurately assess probalities P(X>x) which are
             used in one-tailed tests.
             .
             * A @stdDev@ function is added to the @Variance@ class for
             distributions.
             .
             * The constructor @S.Distribution.normalDistr@ now takes standard
             deviation instead of variance as its parameter.
             .
             * A bug in @S.Quantile.weightedAvg@ is fixed. It produced a wrong
             answer if a sample contained only one element.
             .
             * Bugs in quantile estimations for chi-square and gamma distribution
             are fixed.
             .
             * Integer overlow in @mannWhitneyUCriticalValue@ is fixed. It
             produced incorrect critical values for moderately large
             samples. Something around 20 for 32-bit machines and 40 for 64-bit
             ones.
             .
             * A bug in @mannWhitneyUSignificant@ is fixed. If either sample was
             larger than 20, it produced a completely incorrect answer.
             .
             * One- and two-tailed tests in @S.Tests.NonParametric@ are selected
             with sum types instead of @Bool@.
             .
             * Test results returned as enumeration instead of @Bool@.
             .
             * Performance improvements for Mann-Whitney U and Wilcoxon tests.
             .
             * Module @S.Tests.NonParamtric@ is split into @S.Tests.MannWhitneyU@
             and @S.Tests.WilcoxonT@
             .
             * @sortBy@ is added to @S.Function@.
             .
             * Mean and variance for gamma distribution are fixed.
             .
             * Much faster cumulative probablity functions for Poisson and
             hypergeometric distributions.
             .
             * Better density functions for gamma and Poisson distributions.
             .
             * Student-T, Fisher-Snedecor F-distributions and Cauchy-Lorentz
             distrbution are added.
             .
             * The function @S.Function.create@ is removed. Use @generateM@ from
             the @vector@ package instead.
             .
             * Function to perform approximate comparion of doubles is added to
             @S.Function.Comparison@
             .
             * Regularized incomplete beta function and its inverse are added to
             @S.Function@.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: Statistics.Autocorrelation Statistics.Constants
                 Statistics.Distribution Statistics.Distribution.Beta
                 Statistics.Distribution.Binomial
                 Statistics.Distribution.CauchyLorentz
                 Statistics.Distribution.ChiSquared
                 Statistics.Distribution.Exponential
                 Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
                 Statistics.Distribution.Geometric
                 Statistics.Distribution.Hypergeometric
                 Statistics.Distribution.Normal Statistics.Distribution.Poisson
                 Statistics.Distribution.StudentT Statistics.Distribution.Transform
                 Statistics.Distribution.Uniform Statistics.Function Statistics.Math
                 Statistics.Math.RootFinding Statistics.Quantile
                 Statistics.Resampling Statistics.Resampling.Bootstrap
                 Statistics.Sample Statistics.Sample.Histogram
                 Statistics.Sample.KernelDensity
                 Statistics.Sample.KernelDensity.Simple Statistics.Sample.Powers
                 Statistics.Test.NonParametric Statistics.Test.ChiSquared
                 Statistics.Test.KolmogorovSmirnov Statistics.Test.MannWhitneyU
                 Statistics.Test.WilcoxonT Statistics.Test.Types
                 Statistics.Transform Statistics.Types
hidden-modules: Statistics.Distribution.Poisson.Internal
                Statistics.Function.Comparison Statistics.Internal
                Statistics.Test.Internal
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/statistics-0.10.3.1
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/statistics-0.10.3.1
              /usr/local/lib
hs-libraries: HSstatistics-0.10.3.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.6.0.1-f7bdc8987bd5928e0ee6e8cc8b246a88
         deepseq-1.3.0.1-5cc4cd89bdc2e8f6db1833d95ec36926
         erf-2.0.0.0-ef0b463281886c7c9a8d7acc67d5b982
         math-functions-0.1.3.0-78d482fe34e8be41a3a34b5a2164d843
         monad-par-0.3.4.2-7cc79868c6e9af5259ba452fac483d89
         mwc-random-0.12.0.1-0eb81e69e8af3373af6d996297c93350
         primitive-0.5.0.1-8e5f40b409f7bb31ae1acfb125279700
         vector-0.10.0.1-869166d5d49db46ce6c328ea5f8defbf
         vector-algorithms-0.5.4.2-121a1f6b21832cab9f9b2bcd06ce88a8
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/statistics-0.10.3.1/html/statistics.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/statistics-0.10.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
